@@ -7,6 +7,7 @@
 #include <stdio.h>
 #include <stdarg.h>
 #include <gtk/gtk.h>
+#include <locale.h>
 
 #include "gnome.h"
 
@@ -281,6 +282,7 @@ edit_setup(void)
 int
 main (int argc, char **argv)
 {
+				setlocale(LC_ALL, "");
         bindtextdomain (PACKAGE, GNOMELOCALEDIR);
         textdomain (PACKAGE);
 
